@@ -50,11 +50,7 @@ class Rethink_DBS(GeneralData):
         if self:
             self.save_log(msg, level)
 
-
-    def __del__(self):
-        loop = asyncio.get_event_loop()
-        asyncio.run(self.close())
-        
+       
 
     @property
     def client_address(self):
@@ -393,7 +389,8 @@ class Rethink_DBS(GeneralData):
                               filter_exp,
                               filter_opt: dict,
                               order_by: str,
-                              options={}):
+                              options={}, 
+                              fields=[]):
         """
         filter expression could ve a json like:
         {'age':30} or an expression:
@@ -419,14 +416,17 @@ class Rethink_DBS(GeneralData):
                     else:
                         lower = filter_exp[0]
                         upper = filter_exp[1]
+
                     query = rdb.db(dbname).table(table_name).between(
                         lower,
                         upper,
                         index=index,
                         left_bound="open",
-                        right_bound="open").coerce_to("array").order_by(
-                            index).run(self.session)
-                    result = await query
+                        right_bound="open").coerce_to("array")
+                    if index in fields:
+                        query = query.pluck(fields)
+
+                    result = await query.order_by(index).run(self.session)
                     return result
                 else:
                     self.logger.info(
